darkhistory.history — DarkHistory documentation

# darkhistory.history

Classes and functions for computing temperature and ionization histories.

Modules

`histools` | Functions and classes for processing lists of transfer functions.
`reionization` | Reionization model.
`tla` | Three-level atom model and integrator.

#### Previous topic

darkhistory.electrons.ics.nonrel_diff_terms.diff_expansion

#### Next topic

darkhistory.history.histools

### This Page

Show Source